@@ -10,11 +10,11 @@ import warnings
 
 from rasterio._env import (
         GDALEnv, get_gdal_config, set_gdal_config,
-        GDALDataFinder, PROJDataFinder)
+        GDALDataFinder, PROJDataFinder, set_proj_data_search_path)
 from rasterio.compat import string_types, getargspec
 from rasterio.errors import (
     EnvError, GDALVersionError, RasterioDeprecationWarning)
-from rasterio.session import Session, AWSSession, DummySession
+from rasterio.session import Session, DummySession
 
 
 class ThreadEnv(threading.local):
@@ -104,7 +104,7 @@ class Env(object):
         }
 
     def __init__(self, session=None, aws_unsigned=False, profile_name=None,
-                 session_class=AWSSession, **options):
+                 session_class=Session.aws_or_dummy, **options):
         """Create a new GDAL/AWS environment.
 
         Note: this class is a context manager. GDAL isn't configured
@@ -181,18 +181,22 @@ class Env(object):
                     "AWSSession object instead.",
                     RasterioDeprecationWarning
                 )
-                session = AWSSession(session=session)
+                session = Session.aws_or_dummy(session=session)
+
             self.session = session
+
         elif aws_access_key_id or profile_name or aws_unsigned:
-            self.session = AWSSession(
+            self.session = Session.aws_or_dummy(
                 aws_access_key_id=aws_access_key_id,
                 aws_secret_access_key=aws_secret_access_key,
                 aws_session_token=aws_session_token,
                 region_name=region_name,
                 profile_name=profile_name,
                 aws_unsigned=aws_unsigned)
+
         elif 'AWS_ACCESS_KEY_ID' in os.environ and 'AWS_SECRET_ACCESS_KEY' in os.environ:
-            self.session = AWSSession()
+            self.session = Session.from_environ()
+
         else:
             self.session = DummySession()
 
@@ -234,17 +238,21 @@ class Env(object):
         None
 
         """
-        if self.session.hascreds(getenv()):
-            pass
-        else:
-            cred_opts = self.session.get_credential_options()
-            self.options.update(**cred_opts)
-            setenv(**cred_opts)
+        cred_opts = self.session.get_credential_options()
+        self.options.update(**cred_opts)
+        setenv(**cred_opts)
 
     def drivers(self):
         """Return a mapping of registered drivers."""
         return local._env.drivers()
 
+    def _dump_open_datasets(self):
+        """Writes descriptions of open datasets to stderr
+
+        For debugging and testing purposes.
+        """
+        return local._env._dump_open_datasets()
+
     def __enter__(self):
         log.debug("Entering env context: %r", self)
         if local._env is None:
@@ -341,10 +349,13 @@ def delenv():
 
 
 class NullContextManager(object):
+
     def __init__(self):
         pass
+
     def __enter__(self):
         return self
+
     def __exit__(self, *args):
         pass
 
@@ -606,16 +617,34 @@ def require_gdal_version(version, param=None, values=None, is_max_version=False,
 
 if 'GDAL_DATA' not in os.environ:
 
-    path = GDALDataFinder().search()
+    path = GDALDataFinder().search_wheel()
 
     if path:
         os.environ['GDAL_DATA'] = path
-        log.debug("GDAL_DATA not found in environment, set to %r.", path)
+        log.debug("GDAL data found in package, GDAL_DATA set to %r.", path)
 
-if 'PROJ_LIB' not in os.environ:
+    # See https://github.com/mapbox/rasterio/issues/1631.
+    elif GDALDataFinder().find_file("header.dxf"):
+        log.debug("GDAL data files are available at built-in paths")
 
+    else:
+        path = GDALDataFinder().search()
+
+        if path:
+            os.environ['GDAL_DATA'] = path
+            log.debug("GDAL_DATA not found in environment, set to %r.", path)
+
+if "PROJ_LIB" in os.environ:
+    path = os.environ["PROJ_LIB"]
+    set_proj_data_search_path(path)
+
+# See https://github.com/mapbox/rasterio/issues/1631.
+elif PROJDataFinder().has_data():
+    log.debug("PROJ data files are available at built-in paths")
+
+else:
     path = PROJDataFinder().search()
 
     if path:
-        os.environ['PROJ_LIB'] = path
-        log.debug("PROJ data not found in environment, set to %r.", path)
+        log.debug("PROJ data not found in environment, setting to %r.", path)
+        set_proj_data_search_path(path)
